@@ -30,14 +30,12 @@
 #define WFMATH_AXIS_BOX_H
 
 #include <wfmath/const.h>
-#include <wfmath/vector.h>
-#include <wfmath/point.h>
 #include <wfmath/intersect_decls.h>
 
-namespace WFMath {
+#include <memory>
+#include <iosfwd>
 
-template<const int dim> class AxisBox;
-template<const int dim> class Ball;
+namespace WFMath {
 
 template<const int dim>
 bool Intersection(const AxisBox<dim>& a1, const AxisBox<dim>& a2, AxisBox<dim>& out);
@@ -76,7 +74,7 @@ class AxisBox
   /// Construct a copy of a box
   AxisBox(const AxisBox& a) : m_low(a.m_low), m_high(a.m_high) {}
   /// Construct a box from an object passed by Atlas
-  explicit AxisBox(const AtlasInType& a) {fromAtlas(a);}
+  explicit AxisBox(const AtlasInType& a);
 
   friend std::ostream& operator<< <dim>(std::ostream& os, const AxisBox& a);
   friend std::istream& operator>> <dim>(std::istream& is, AxisBox& a);
@@ -87,7 +85,7 @@ class AxisBox
   void fromAtlas(const AtlasInType& a);
 
   AxisBox& operator=(const AxisBox& a)
-	{m_low = a.m_low; m_high = a.m_high; return *this;}
+  {m_low = a.m_low; m_high = a.m_high; return *this;}
 
   bool isEqualTo(const AxisBox& b, double epsilon = WFMATH_EPSILON) const;
   bool operator==(const AxisBox& a) const	{return isEqualTo(a);}
@@ -118,16 +116,16 @@ class AxisBox
    * optimization primarily intended for use inside the library.
    **/
   AxisBox& setCorners(const Point<dim>& p1, const Point<dim>& p2,
-	bool ordered = false);
+  bool ordered = false);
 
   // Movement functions
 
   AxisBox& shift(const Vector<dim>& v)
-	{m_low += v; m_high += v; return *this;}
+  {m_low += v; m_high += v; return *this;}
   AxisBox& moveCornerTo(const Point<dim>& p, int corner)
-	{return shift(p - getCorner(corner));}
+  {return shift(p - getCorner(corner));}
   AxisBox& moveCenterTo(const Point<dim>& p)
-	{return shift(p - getCenter());}
+  {return shift(p - getCenter());}
 
   // No rotation functions, this shape can't rotate
 
@@ -184,6 +182,4 @@ class AxisBox
 
 } // namespace WFMath
 
-#include <wfmath/axisbox_funcs.h>
-
 #endif  // WFMATH_AXIS_BOX_H
