@@ -31,6 +31,10 @@
 #include <wfmath/error.h>
 #include <wfmath/const.h>
 
+#include <cmath>
+
+#include <cassert>
+
 namespace WFMath {
 
 template<const int dim>
